==> haskell-hls-fourmolu-plugin-2.0.0.0-17-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hls-fourmolu-plugin.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hls-fourmolu-plugin
version:              2.0.0.0
visibility:           public
id:                   hls-fourmolu-plugin-2.0.0.0-JM1iV33qMJhJbZJlV3aPOQ
key:                  hls-fourmolu-plugin-2.0.0.0-JM1iV33qMJhJbZJlV3aPOQ
license:              Apache-2.0
copyright:            The Haskell IDE Team
maintainer:           alan.zimm@gmail.com
author:               The Haskell IDE Team
homepage:             https://github.com/haskell/haskell-language-server
synopsis:             Integration with the Fourmolu code formatter
description:
    Please see the README on GitHub at <https://github.com/haskell/haskell-language-server#readme>

category:             Development
abi:                  43e3665832225222c44dc8022628ea78
exposed:              True
exposed-modules:      Ide.Plugin.Fourmolu Ide.Plugin.Fourmolu.Shim
import-dirs:          /usr/lib/ghc-9.4.8/site-local/hls-fourmolu-plugin-2.0.0.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/hls-fourmolu-plugin-2.0.0.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/hls-fourmolu-plugin-2.0.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hls-fourmolu-plugin
hs-libraries:         HShls-fourmolu-plugin-2.0.0.0-JM1iV33qMJhJbZJlV3aPOQ
depends:
    base-4.17.2.1 filepath-1.4.2.2
    fourmolu-0.10.0.0-CmCEdaKpmLRBvlgSTociK8 ghc-9.4.8
    ghc-boot-th-9.4.8 ghcide-2.0.0.0-3b9jhFA8f52IfzEBIRB0hj
    hls-plugin-api-2.0.0.0-C6wcsLywVi7Dk1nbG5XhP7
    lens-5.2.3-9GV2xnL92otDGMRfTuRDyv
    lsp-1.6.0.0-FwDzb2GQtLRAHogbqVnKTH
    process-extras-0.7.4-2cn2wZtibz626j8FA78NHv text-2.0.2

haddock-interfaces:
    /usr/share/doc/haskell-hls-fourmolu-plugin/html/hls-fourmolu-plugin.haddock

haddock-html:         /usr/share/doc/haskell-hls-fourmolu-plugin/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hls-fourmolu-plugin-2.0.0.0-18-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hls-fourmolu-plugin.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hls-fourmolu-plugin
version:              2.0.0.0
visibility:           public
id:                   hls-fourmolu-plugin-2.0.0.0-DUzLdEjVGalD9kBmzkjlTv
key:                  hls-fourmolu-plugin-2.0.0.0-DUzLdEjVGalD9kBmzkjlTv
license:              Apache-2.0
copyright:            The Haskell IDE Team
maintainer:           alan.zimm@gmail.com
author:               The Haskell IDE Team
homepage:             https://github.com/haskell/haskell-language-server
synopsis:             Integration with the Fourmolu code formatter
description:
    Please see the README on GitHub at <https://github.com/haskell/haskell-language-server#readme>

category:             Development
abi:                  5be3f0d2b918802de7c37e52f38d28c1
exposed:              True
exposed-modules:      Ide.Plugin.Fourmolu Ide.Plugin.Fourmolu.Shim
import-dirs:          /usr/lib/ghc-9.4.8/site-local/hls-fourmolu-plugin-2.0.0.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/hls-fourmolu-plugin-2.0.0.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/hls-fourmolu-plugin-2.0.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hls-fourmolu-plugin
hs-libraries:         HShls-fourmolu-plugin-2.0.0.0-DUzLdEjVGalD9kBmzkjlTv
depends:
    base-4.17.2.1 filepath-1.4.2.2
    fourmolu-0.10.0.0-Fbm6R1Kv8Te3fm1dGfJCps ghc-9.4.8
    ghc-boot-th-9.4.8 ghcide-2.0.0.0-L5q9I4ZYiMTCYArbowTz3S
    hls-plugin-api-2.0.0.0-1mAvF1as5w95rctfx0vZ4l
    lens-5.2.3-1xyXEUn2kF27mSgPIa0sOB
    lsp-1.6.0.0-G6O3LkQ8zqqEpZl3VXzGEp
    process-extras-0.7.4-2cn2wZtibz626j8FA78NHv text-2.0.2

haddock-interfaces:
    /usr/share/doc/haskell-hls-fourmolu-plugin/html/hls-fourmolu-plugin.haddock

haddock-html:         /usr/share/doc/haskell-hls-fourmolu-plugin/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
